var diff = require('../index');
var should = require('should');

describe("collectionDiff", function(){
	it ("throws an exception if it doesn't get an array as the first input", function(){
		try {
			diff(1234, []);
			should.fail("expected exception was not thrown");
		} catch(ex){
			ex.should.equal("the first two arguments must be arrays");		
		}
	});
	it ("throws an exception if it doesn't get an array as the second input", function(){
		try {
			diff([], 1234);
			should.fail("expected exception was not thrown");
		} catch(ex){
			ex.should.equal("the first two arguments must be arrays");		
		}
	});
	it ("can diff two empty arrays and returns an empty array", function(){
		diff([], []).should.eql([]);
	});
	it ("can diff two arrays where one is non-empty", function(){
		diff([], [{asdf:true}])
			.should.eql([{ change : 'list2', row : {asdf:true}}]);
	});
	it ("can diff a simple complete diff by showing both rows", function(){
		diff([{asdf:true}], [{asdf:false}])
			.should.eql([
				{ change : 'list1', row : {asdf:true}},
				{ change : 'list2', row : {asdf:false}}
			]);
	});
	it ("can diff a simple reverse diff", function(){
		diff([{asdf:true}, {qwer:true}], [{qwer:true}, {asdf:true}])
			.should.eql([
				{ change : false, row : {asdf:true}},
				{ change : false, row : {qwer:true}}
			]);
	});
	it ("can ignore a field", function(){
		diff([{asdf:true, id : 1234}, {qwer:true, id:5678}], 
         [{qwer:true, id :9101112}, {asdf:true, id : 13141516}], {ignoreFields : ['id']})
			.should.eql([
				{ change : false, row : {asdf:true}},
				{ change : false, row : {qwer:true}}
			]);
	});
});
